@@ -17,7 +17,7 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #
-export LC_MESSAGES=C
+export LC_MESSAGES=C kernel
 
 if [[ $EUID == "0" ]] && ! [[ ${DRACUT_NO_XATTR-} ]]; then
     export DRACUT_CP="cp --reflink=auto --sparse=auto --preserve=mode,timestamps,xattr,links -dfr"
@@ -53,11 +53,6 @@ if ! [[ -d $initdir ]]; then
     mkdir -p "$initdir"
 fi
 
-if ! [[ ${kernel-} ]]; then
-    kernel=$(uname -r)
-    export kernel
-fi
-
 srcmods="$(realpath -e "${dracutsysrootdir-}/lib/modules/$kernel")"
 
 [[ ${drivers_dir-} ]] && {
@@ -245,7 +240,7 @@ inst_dir() {
 inst() {
     local dstdir="${dstdir:-"$initdir"}"
     local _ret _hostonly_install
-    if [[ $1 == "-H" ]]; then
+    if [[ $1 == "-H" ]] && [[ $hostonly ]]; then
         _hostonly_install="-H"
         shift
     fi
@@ -262,7 +257,7 @@ inst() {
 inst_simple() {
     local dstdir="${dstdir:-"$initdir"}"
     local _ret _hostonly_install
-    if [[ $1 == "-H" ]]; then
+    if [[ $1 == "-H" ]] && [[ $hostonly ]]; then
         _hostonly_install="-H"
         shift
     fi
@@ -283,7 +278,7 @@ inst_simple() {
 
 inst_symlink() {
     local _ret _hostonly_install
-    if [[ $1 == "-H" ]]; then
+    if [[ $1 == "-H" ]] && [[ $hostonly ]]; then
         _hostonly_install="-H"
         shift
     fi
@@ -301,7 +296,7 @@ inst_symlink() {
 inst_multiple() {
     local dstdir="${dstdir:-"$initdir"}"
     local _ret _hostonly_install
-    if [[ $1 == "-H" ]]; then
+    if [[ $1 == "-H" ]] && [[ $hostonly ]]; then
         _hostonly_install="-H"
         shift
     fi
@@ -480,15 +475,15 @@ inst_rule_group_owner() {
 
     # shellcheck disable=SC2013
     for i in $(sed -nr 's/.*OWNER=?"([^ "]+).*/\1/p' "$1"); do
-        if ! grep -Eq "^$i:" "$initdir/etc/passwd" 2> /dev/null; then
-            grep -E "^$i:" "${dracutsysrootdir-}/etc/passwd" 2> /dev/null >> "$initdir/etc/passwd"
+        if ! grep -Eqs "^$i:" "$initdir/etc/passwd"; then
+            grep -Es "^$i:" "${dracutsysrootdir-}/etc/passwd" >> "$initdir/etc/passwd"
         fi
     done
 
     # shellcheck disable=SC2013
     for i in $(sed -nr 's/.*GROUP=?"([^ "]+).*/\1/p' "$1"); do
-        if ! grep -Eq "^$i:" "$initdir/etc/group" 2> /dev/null; then
-            grep -E "^$i:" "${dracutsysrootdir-}/etc/group" 2> /dev/null >> "$initdir/etc/group"
+        if ! grep -Eqs "^$i:" "$initdir/etc/group"; then
+            grep -Es "^$i:" "${dracutsysrootdir-}/etc/group" >> "$initdir/etc/group"
         fi
     done
 }
@@ -695,7 +690,6 @@ module_functions=(
 
 # module_check <dracut module> [<forced>] [<module path>]
 # execute the check() function of module-setup.sh of <dracut module>
-# or the "check" script, if module-setup.sh is not found
 # "check $hostonly" is called
 module_check() {
     local _moddir=$3
@@ -722,7 +716,6 @@ module_check() {
 
 # module_check_mount <dracut module> [<module path>]
 # execute the check() function of module-setup.sh of <dracut module>
-# or the "check" script, if module-setup.sh is not found
 # "mount_needs=1 check 0" is called
 module_check_mount() {
     local _moddir=$2
@@ -743,7 +736,6 @@ module_check_mount() {
 
 # module_depends <dracut module> [<module path>]
 # execute the depends() function of module-setup.sh of <dracut module>
-# or the "depends" script, if module-setup.sh is not found
 module_depends() {
     local _moddir=$2
     local _ret
@@ -761,7 +753,6 @@ module_depends() {
 
 # module_cmdline <dracut module> [<module path>]
 # execute the cmdline() function of module-setup.sh of <dracut module>
-# or the "cmdline" script, if module-setup.sh is not found
 module_cmdline() {
     local _moddir=$2
     local _ret
@@ -779,7 +770,6 @@ module_cmdline() {
 
 # module_config <dracut module> [<module path>]
 # execute the config() function of module-setup.sh of <dracut module>
-# or the "config" script, if module-setup.sh is not found
 module_config() {
     local _moddir=$2
     local _ret
@@ -797,7 +787,6 @@ module_config() {
 
 # module_install <dracut module> [<module path>]
 # execute the install() function of module-setup.sh of <dracut module>
-# or the "install" script, if module-setup.sh is not found
 module_install() {
     local _moddir=$2
     local _ret
@@ -815,7 +804,6 @@ module_install() {
 
 # module_installkernel <dracut module> [<module path>]
 # execute the installkernel() function of module-setup.sh of <dracut module>
-# or the "installkernel" script, if module-setup.sh is not found
 module_installkernel() {
     local _moddir=$2
     local _ret
