@@ -3,7 +3,7 @@
 # called by dracut
 check() {
     # a live host-only image doesn't really make a lot of sense
-    [[ ${hostonly-} ]] && return 1
+    [[ $hostonly ]] && return 1
     return 255
 }
 
@@ -22,7 +22,7 @@ installkernel() {
 
 # called by dracut
 install() {
-    inst_multiple umount dmsetup blkid dd losetup blockdev find rmdir grep
+    inst_multiple umount dmsetup blkid dd losetup blockdev find rmdir grep stat
     inst_multiple -o checkisomd5
     inst_hook cmdline 30 "$moddir/parse-dmsquash-live.sh"
     inst_hook cmdline 31 "$moddir/parse-iso-scan.sh"
